@@ -39,6 +39,14 @@ using std::make_pair;
 namespace MediaInfoLib
 {
 
+enum basicformat
+{
+    BasicFormat_Text,
+    BasicFormat_CSV,
+    BasicFormat_XML,
+    BasicFormat_JSON,
+};
+
 //***************************************************************************
 // Class MediaInfo_Config
 //***************************************************************************
@@ -179,6 +187,7 @@ public :
     const ZtringListList &Info_Get(stream_t KindOfStream); //Should not be, but too difficult to hide it
 
           Ztring    Info_Parameters_Get (bool Complete=false);
+          Ztring    Info_OutputFormats_Get(basicformat Format);
           Ztring    Info_Tags_Get       () const;
           Ztring    Info_CodecsID_Get   ();
           Ztring    Info_Codecs_Get     ();
@@ -208,6 +217,8 @@ public :
           int64u    MpegTs_MaximumScanDuration_Get ();
           void      MpegTs_ForceStreamDisplay_Set (bool Value);
           bool      MpegTs_ForceStreamDisplay_Get ();
+          void      MpegTs_ForceTextStreamDisplay_Set(bool Value);
+          bool      MpegTs_ForceTextStreamDisplay_Get();
     #if MEDIAINFO_ADVANCED
           void      MpegTs_VbrDetection_Delta_Set (float64 Value);
           float64   MpegTs_VbrDetection_Delta_Get ();
@@ -227,6 +238,11 @@ public :
           bool        Format_Profile_Split_Get ();
     #endif //MEDIAINFO_ADVANCED
 
+    #if defined(MEDIAINFO_EBUCORE_YES)
+          void        AcquisitionDataOutputMode_Set (size_t Value);
+          size_t      AcquisitionDataOutputMode_Get ();
+    #endif //MEDIAINFO_EBUCORE_YES
+
     ZtringListList  SubFile_Config_Get ();
 
     void            CustomMapping_Set (const Ztring &Value);
@@ -251,6 +267,14 @@ public :
 
     #if defined(MEDIAINFO_LIBCURL_YES)
           bool      CanHandleUrls();
+          enum urlencode
+          {
+              URLEncode_No,
+              URLEncode_Guess,
+              URLEncode_Yes,
+          };
+          void      URLEncode_Set(urlencode NewValue);
+          urlencode URLEncode_Get();
           void      Ssh_PublicKeyFileName_Set (const Ztring &NewValue);
           Ztring    Ssh_PublicKeyFileName_Get ();
           void      Ssh_PrivateKeyFileName_Set (const Ztring &NewValue);
@@ -292,6 +316,7 @@ private :
     int64u          MpegTs_MaximumOffset;
     int64u          MpegTs_MaximumScanDuration;
     bool            MpegTs_ForceStreamDisplay;
+    bool            MpegTs_ForceTextStreamDisplay;
     #if MEDIAINFO_ADVANCED
         float64     MpegTs_VbrDetection_Delta;
         int64u      MpegTs_VbrDetection_Occurences;
@@ -300,6 +325,9 @@ private :
     #if MEDIAINFO_ADVANCED
         bool        Format_Profile_Split;
     #endif //MEDIAINFO_ADVANCED
+    #if defined(MEDIAINFO_EBUCORE_YES)
+        size_t      AcquisitionDataOutputMode;
+    #endif //defined(MEDIAINFO_EBUCORE_YES)
     size_t          Complete;
     size_t          BlockMethod;
     size_t          Internet;
@@ -360,6 +388,7 @@ private :
     #endif //MEDIAINFO_EVENTS
 
     #if defined(MEDIAINFO_LIBCURL_YES)
+          urlencode URLEncode;
           Ztring    Ssh_PublicKeyFileName;
           Ztring    Ssh_PrivateKeyFileName;
           Ztring    Ssh_KnownHostsFileName;
